@@ -42,6 +42,7 @@ class Service(ToDictMixin):
         self.iid = accessory.get_next_id()
         self.characteristics = []
         self.characteristics_by_type = {}
+        self.linked = []
 
         if name:
             char = self.add_char(CharacteristicsTypes.NAME)
@@ -52,6 +53,31 @@ class Service(ToDictMixin):
                 if required not in self.characteristics_by_type:
                     self.add_char(required)
 
+    @property
+    def short_type(self):
+        try:
+            return ServicesTypes.get_short_uuid(self.type)
+        except KeyError:
+            return self.type
+
+    @property
+    def type_name(self):
+        try:
+            return ServicesTypes.get_short(self.type)
+        except KeyError:
+            return None
+
+    def value(self, char_type, default_value=None):
+        try:
+            char_type = CharacteristicsTypes.get_uuid(char_type)
+        except KeyError:
+            pass
+
+        if char_type not in self.characteristics_by_type:
+            return default_value
+
+        return self.characteristics_by_type[char_type].value
+
     def __getitem__(self, key):
         try:
             key = CharacteristicsTypes.get_uuid(key)
@@ -65,6 +91,9 @@ class Service(ToDictMixin):
         self.characteristics_by_type[char.type] = char
         return char
 
+    def add_linked_service(self, service: "Service"):
+        self.linked.append(service)
+
     def to_accessory_and_service_list(self):
         characteristics_list = []
         for c in self.characteristics:
@@ -74,4 +103,9 @@ class Service(ToDictMixin):
             "type": self.type,
             "characteristics": characteristics_list,
         }
+
+        linked = [service.iid for service in self.linked]
+        if linked:
+            d["linked"] = linked
+
         return d
